@@ -30,6 +30,7 @@ import locale
 import os
 import sys
 
+import app_prefs
 import braille
 import debug
 import default
@@ -76,6 +77,19 @@ class orcaSetupGUI(orca_gui_prefs.orcaSetupGUI):
             label = gtk.Label(orca_state.locusOfFocus.app.name)
             self.notebook.append_page(vbox, label)
 
+    def _createPronunciationTreeView(self, pronunciations=None):
+        """Create the pronunciation dictionary tree view for this specific 
+        application. We call the super class method passing in the 
+        application specific pronunciation dictionary.
+
+        Arguments:
+        - pronunciations: an optional dictionary used to get the
+          pronunciation from.
+        """
+
+        orca_gui_prefs.orcaSetupGUI._createPronunciationTreeView( \
+                              self, appScript.app_pronunciation_dict)
+
     def _showGUI(self):
         """Show the app-specific Orca configuration GUI window. This 
         assumes that the GUI has already been created.
@@ -95,9 +109,9 @@ class orcaSetupGUI(orca_gui_prefs.orcaSetupGUI):
         """Write out the user's application-specific Orca preferences.
         """
         moduleName = settings.getScriptModuleName(self.app)
-        orca_prefs.writeAppPreferences(self.prefsDict, moduleName,
-                                       self.appScript, self.keyBindingsModel,
-                                       self.pronunciationModel)
+        app_prefs.writePreferences(self.prefsDict, moduleName,
+                                   self.appScript, self.keyBindingsModel,
+                                   self.pronunciationModel)
         ftp = focus_tracking_presenter.FocusTrackingPresenter()
         ftp.loadAppSettings(self.appScript)
 
