@@ -19,9 +19,9 @@
 
 """Provides the interface to the AT-SPI Registry."""
 
-__id__        = "$Id: atspi.py 2721 2007-08-26 20:07:53Z joanied $"
-__version__   = "$Revision: 2721 $"
-__date__      = "$Date: 2007-08-26 16:07:53 -0400 (Sun, 26 Aug 2007) $"
+__id__        = "$Id: atspi.py 2821 2007-09-12 14:28:07Z wwalker $"
+__version__   = "$Revision: 2821 $"
+__date__      = "$Date: 2007-09-12 10:28:07 -0400 (Wed, 12 Sep 2007) $"
 __copyright__ = "Copyright (c) 2005-2007 Sun Microsystems Inc."
 __license__   = "LGPL"
 
@@ -91,12 +91,12 @@ class Event:
             # http://bugzilla.gnome.org/show_bug.cgi?id=395749 for
             # more information.
             #
-            if self.type == "object:active-descendant-changed":
+            if self.type.startswith("object:active-descendant-changed"):
                 self.any_data = Accessible.makeAccessible(
                     self.any_data.value())
-            elif self.type == "object:text-changed:insert":
+            elif self.type.startswith("object:text-changed:insert"):
                 self.any_data = self.any_data.value()
-            elif self.type == "object:text-changed:delete":
+            elif self.type.startswith("object:text-changed:delete"):
                 self.any_data = self.any_data.value()
         else:
             self.source   = None
@@ -535,7 +535,7 @@ class Accessible:
         if Accessible._cache.has_key(e.source):
             # Let's get rid of defunct objects.  We hate them.
             #
-            if e.type == "object:state-changed:defunct":
+            if e.type.startswith("object:state-changed:defunct"):
                 Accessible.deleteAccessible(e.source)
             else:
                 obj = Accessible._cache[e.source]
