@@ -25,9 +25,9 @@ operations on the Accessible object, such as invoking default actions or
 moving the text caret.
 """
 
-__id__        = "$Id: braille.py 2538 2007-07-12 19:40:46Z joanied $"
-__version__   = "$Revision: 2538 $"
-__date__      = "$Date: 2007-07-12 15:40:46 -0400 (Thu, 12 Jul 2007) $"
+__id__        = "$Id: braille.py 2602 2007-08-08 17:15:07Z shaeger $"
+__version__   = "$Revision: 2602 $"
+__date__      = "$Date: 2007-08-08 13:15:07 -0400 (Wed, 08 Aug 2007) $"
 __copyright__ = "Copyright (c) 2005-2007 Sun Microsystems Inc."
 __license__   = "LGPL"
 
@@ -435,6 +435,8 @@ class Text(Region):
         selection."""
 
         text = self.accessible.text
+        if not text:
+            return ''
 
         # Start with an empty mask.
         #
