@@ -23,9 +23,9 @@ class.  For those wishing to override the braille generators, however,
 one can create a new instance and replace/extend the braille
 generators as they see fit."""
 
-__id__        = "$Id: braillegenerator.py 3011 2007-10-10 20:27:20Z joanied $"
-__version__   = "$Revision: 3011 $"
-__date__      = "$Date: 2007-10-10 16:27:20 -0400 (Wed, 10 Oct 2007) $"
+__id__        = "$Id: braillegenerator.py 2959 2007-10-01 22:30:24Z richb $"
+__version__   = "$Revision: 2959 $"
+__date__      = "$Date: 2007-10-01 18:30:24 -0400 (Mon, 01 Oct 2007) $"
 __copyright__ = "Copyright (c) 2005-2007 Sun Microsystems Inc."
 __license__   = "LGPL"
 
@@ -95,6 +95,8 @@ class BrailleGenerator:
              self._getBrailleRegionsForLabel
         self.brailleGenerators[rolenames.ROLE_LIST]                = \
              self._getBrailleRegionsForList
+        self.brailleGenerators[rolenames.ROLE_LIST_ITEM]           = \
+             self._getBrailleRegionsForListItem
         self.brailleGenerators[rolenames.ROLE_MENU]                = \
              self._getBrailleRegionsForMenu
         self.brailleGenerators[rolenames.ROLE_MENU_BAR]            = \
@@ -668,6 +670,58 @@ class BrailleGenerator:
 
         return self._getDefaultBrailleRegions(obj)
 
+    def _getBrailleRegionsForListItem(self, obj):
+        """Get the braille for a listitem.
+
+        Arguments:
+        - obj: the listitem
+
+        """
+
+        self._debugGenerator("_getBrailleRegionsForListItem", obj)
+
+        text = ""
+        text = self._script.appendString(
+            text, self._script.getDisplayedLabel(obj))
+        text = self._script.appendString(
+            text, self._script.getDisplayedText(obj))
+
+        if obj.state.count(atspi.Accessibility.STATE_EXPANDABLE):
+            if obj.state.count(atspi.Accessibility.STATE_EXPANDED):
+                # Translators: this represents the state of a node in a tree.
+                # 'expanded' means the children are showing.
+                # 'collapsed' means the children are not showing.
+                #
+                text = self._script.appendString(text, _('expanded'))
+            else:
+                # Translators: this represents the state of a node in a tree.
+                # 'expanded' means the children are showing.
+                # 'collapsed' means the children are not showing.
+                #
+                text = self._script.appendString(text, _('collapsed'))
+
+        if obj == orca_state.locusOfFocus:
+            text = self._script.appendString(
+                text, self._getTextForRole(obj))
+            text = self._script.appendString(
+                text, self._getTextForAvailability(obj))
+            text = self._script.appendString(
+                text, self._getTextForAccelerator(obj), "")
+
+        level = self._script.getNodeLevel(obj)
+        if level >= 0:
+            # Translators: this represents the depth of a node in a tree
+            # view (i.e., how many ancestors a node has).
+            #
+            text = self._script.appendString(text, _("LEVEL %d") \
+                                             % (level + 1))
+
+        regions = []
+        componentRegion = braille.Component(obj, text)
+        regions.append(componentRegion)
+
+        return [regions, componentRegion]
+
     def _getBrailleRegionsForMenu(self, obj):
         """Get the braille for a menu.
 
@@ -1230,6 +1284,14 @@ class BrailleGenerator:
                 #
                 regions[0].append(braille.Region(" " + _("collapsed")))
 
+        level = self._script.getNodeLevel(obj)
+        if level >= 0:
+            # Translators: this represents the depth of a node in a tree
+            # view (i.e., how many ancestors a node has).
+            #
+            regions[0].append(braille.Region(" " + _("TREE LEVEL %d") \
+                                             % (level + 1)))
+
         return regions
 
     def _getBrailleRegionsForTableCellRow(self, obj):
@@ -1268,11 +1330,12 @@ class BrailleGenerator:
             # the same row).
             #
             speakAll = True
-            if parent.__dict__.has_key("lastRow") and \
-                parent.__dict__.has_key("lastColumn"):
-                speakAll = (parent.lastRow != row) or \
+            if self._script.pointOfReference.has_key("lastRow") and \
+                self._script.pointOfReference.has_key("lastColumn"):
+                pointOfReference = self._script.pointOfReference
+                speakAll = (pointOfReference["lastRow"] != row) or \
                        ((row == 0 or row == parent.table.nRows-1) and \
-                        parent.lastColumn == column)
+                        pointOfReference["lastColumn"] == column)
 
             if speakAll:
                 focusRowRegion = None
@@ -1296,14 +1359,6 @@ class BrailleGenerator:
         else:
             regions = self._getBrailleRegionsForTableCell(obj)
 
-        level = self._script.getNodeLevel(obj)
-        if level >= 0:
-            # Translators: this represents the depth of a node in a tree
-            # view (i.e., how many ancestors a node has).
-            #
-            regions[0].append(braille.Region(" " + _("TREE LEVEL %d") \
-                                             % (level + 1)))
-
         return regions
 
     def _getBrailleRegionsForTableColumnHeader(self, obj):
