@@ -18,19 +18,20 @@
 # Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 # Boston, MA 02111-1307, USA.
 
-"""Provides a methods that converts the role name of an Accessible
+"""Provides methods that convert the role name of an Accessible
 object into localized strings for speech and braille."""
 
-__id__        = "$Id: rolenames.py 2279 2007-04-11 15:10:57Z wwalker $"
-__version__   = "$Revision: 2279 $"
-__date__      = "$Date: 2007-04-11 11:10:57 -0400 (Wed, 11 Apr 2007) $"
+__id__        = "$Id: rolenames.py 2800 2007-09-07 13:59:36Z wwalker $"
+__version__   = "$Revision: 2800 $"
+__date__      = "$Date: 2007-09-07 09:59:36 -0400 (Fri, 07 Sep 2007) $"
 __copyright__ = "Copyright (c) 2004-2007 Sun Microsystems Inc."
 __license__   = "LGPL"
 
 import debug
 import settings
 
-from orca_i18n import _ # for gettext support
+from orca_i18n import _  # for gettext support
+from orca_i18n import Q_ # to provide qualified translatable strings
 
 ########################################################################
 #                                                                      #
@@ -100,6 +101,7 @@ ROLE_SECTION             = "section"
 ROLE_SEPARATOR           = "separator"
 ROLE_SLIDER              = "slider"
 ROLE_SPLIT_PANE          = "split pane"
+ROLE_SPIN_BOX            = "spinbox"
 ROLE_SPIN_BUTTON         = "spin button"
 ROLE_STATUSBAR           = "statusbar"
 ROLE_TABLE               = "table"
@@ -378,8 +380,13 @@ rolenames[ROLE_DESKTOP_FRAME] = Rolename(
 rolenames[ROLE_DIAL] = Rolename(
     ROLE_DIAL,
     # Translators: short braille for the rolename of a dial.
+    # You should attempt to treat it as an abbreviation of
+    # the translated word for "dial".  It is OK to use an
+    # unabbreviated word as long as it is relatively short.
     #
-    _("dial"),
+    # ONLY TRANSLATE THE PART AFTER THE PIPE CHARACTER |
+    #
+    Q_("shortbraille|dial"),
     # Translators: long braille for the rolename of a dial.
     #
     _("Dial"),
@@ -474,8 +481,13 @@ rolenames[ROLE_FONT_CHOOSER] = Rolename(
 rolenames[ROLE_FORM] = Rolename(
     ROLE_FORM,
     # Translators: short braille for the rolename of a form.
+    # You should attempt to treat it as an abbreviation of
+    # the translated word for "form".  It is OK to use an
+    # unabbreviated word as long as it is relatively short.
     #
-    _("form"),
+    # ONLY TRANSLATE THE PART AFTER THE PIPE CHARACTER |
+    #
+    Q_("shortbraille|form"),
     # Translators: long braille for the rolename of a form.
     #
     _("Form"),
