@@ -19,9 +19,9 @@
 
 """Custom script for StarOffice and OpenOffice."""
 
-__id__        = "$Id: StarOffice.py 2828 2007-09-13 19:26:33Z wwalker $"
-__version__   = "$Revision: 2828 $"
-__date__      = "$Date: 2007-09-13 15:26:33 -0400 (Thu, 13 Sep 2007) $"
+__id__        = "$Id: StarOffice.py 2936 2007-09-27 19:46:45Z eitani $"
+__version__   = "$Revision: 2936 $"
+__date__      = "$Date: 2007-09-27 15:46:45 -0400 (Thu, 27 Sep 2007) $"
 __copyright__ = "Copyright (c) 2005-2007 Sun Microsystems Inc."
 __license__   = "LGPL"
 
@@ -251,8 +251,9 @@ class BrailleGenerator(braillegenerator.BrailleGenerator):
         table = self._script.getTable(obj)
         parent = obj.parent
 
-        if parent.__dict__.has_key("lastColumn") and \
-           parent.lastColumn != parent.table.getColumnAtIndex(obj.index):
+        if self._script.pointOfReference.has_key("lastColumn") and \
+              self._script.pointOfReference["lastColumn"] != \
+              parent.table.getColumnAtIndex(obj.index):
             if self._script.dynamicColumnHeaders.has_key(table):
                 row = self._script.dynamicColumnHeaders[table]
                 header = self._script.getDynamicRowHeaderCell(obj, row)
@@ -267,8 +268,9 @@ class BrailleGenerator(braillegenerator.BrailleGenerator):
                     if text:
                         regions.append(braille.Region(" " + text + " "))
 
-        if parent.__dict__.has_key("lastRow") and \
-           parent.lastRow != parent.table.getRowAtIndex(obj.index):
+        if self._script.pointOfReference.has_key("lastRow") and \
+              self._script.pointOfReference['lastRow'] != \
+              parent.table.getRowAtIndex(obj.index):
             if self._script.dynamicRowHeaders.has_key(table):
                 column = self._script.dynamicRowHeaders[table]
                 header = self._script.getDynamicColumnHeaderCell(obj, column)
@@ -305,11 +307,13 @@ class BrailleGenerator(braillegenerator.BrailleGenerator):
                 # the same row).
                 #
                 speakAll = True
-                if parent.__dict__.has_key("lastRow") and \
-                    parent.__dict__.has_key("lastColumn"):
-                    speakAll = (parent.lastRow != row) or \
+                if self._script.pointOfReference.has_key("lastRow") and \
+                    self._script.pointOfReference.has_key("lastColumn"):
+                    pointOfReference = self._script.pointOfReference
+                    speakAll = \
+                        (pointOfReference["lastRow"] != row) or \
                            ((row == 0 or row == parent.table.nRows-1) and \
-                            parent.lastColumn == column)
+                            pointOfReference["lastColumn"] == column)
 
                 if speakAll:
                     focusRowRegion = None
@@ -513,8 +517,8 @@ class SpeechGenerator(speechgenerator.SpeechGenerator):
             table = self._script.getTable(obj)
             parent = obj.parent
 
-            if parent.__dict__.has_key("lastColumn") and \
-               parent.lastColumn != \
+            if self._script.pointOfReference.has_key("lastColumn") and \
+               self._script.pointOfReference["lastColumn"] != \
                parent.table.getColumnAtIndex(obj.index):
                 if self._script.dynamicColumnHeaders.has_key(table):
                     row = self._script.dynamicColumnHeaders[table]
@@ -530,8 +534,9 @@ class SpeechGenerator(speechgenerator.SpeechGenerator):
                         if text:
                             utterances.append(text)
 
-            if parent.__dict__.has_key("lastRow") and \
-               parent.lastRow != parent.table.getRowAtIndex(obj.index):
+            if self._script.pointOfReference.has_key("lastRow") and \
+               self._script.pointOfReference["lastRow"] != \
+               parent.table.getRowAtIndex(obj.index):
                 if self._script.dynamicRowHeaders.has_key(table):
                     column = self._script.dynamicRowHeaders[table]
                     header = self._script.getDynamicColumnHeaderCell(obj,
@@ -560,11 +565,12 @@ class SpeechGenerator(speechgenerator.SpeechGenerator):
                     # the same row).
                     #
                     speakAll = True
-                    if parent.__dict__.has_key("lastRow") and \
-                        parent.__dict__.has_key("lastColumn"):
-                        speakAll = (parent.lastRow != row) or \
+                    if self._script.pointOfReference.has_key("lastRow") and \
+                        self._script.pointOfReference.has_key("lastColumn"):
+                        pointOfReference = self._script.pointOfReference
+                        speakAll = (pointOfReference["lastRow"] != row) or \
                                ((row == 0 or row == parent.table.nRows-1) and \
-                                parent.lastColumn == column)
+                                pointOfReference["lastColumn"] == column)
 
                     if speakAll:
                         [startIndex, endIndex] = \
@@ -1518,6 +1524,57 @@ class Script(default.Script):
         for label in allLabels:
             self.speakSetupLabel(label)
 
+    def __isAvailableFieldsPanel(self, event):
+        """If we are in the sbase Table Wizard, try to reduce the numerous
+        utterances of "Available fields panel". See bug #465087 for more 
+        details.
+
+        Arguments:
+        - event: the object state change event.
+        """
+
+        # Translators: this represents a match with the name of the
+        # "Available fields" list in the Tables wizard dialog in the
+        # the OOo oobase database application. We're looking for the
+        # accessible object name starting with "Available fields".
+        # We really try to avoid doing this kind of thing, but
+        # sometimes it is necessary and we apologize.
+        #
+        panelName = _("Available fields")
+
+        isPanel = False
+        if event.type == "object:state-changed:focused":
+            rolesList = [rolenames.ROLE_PANEL, \
+                         rolenames.ROLE_SCROLL_PANE, \
+                         rolenames.ROLE_PANEL, \
+                         rolenames.ROLE_OPTION_PANE, \
+                         rolenames.ROLE_DIALOG, \
+                         rolenames.ROLE_APPLICATION]
+            if self.isDesiredFocusedItem(event.source, rolesList):
+                if event.source.parent.parent.name.startswith(panelName):
+                    isPanel = True
+
+            if not isPanel:
+                rolesList = [rolenames.ROLE_SCROLL_PANE, \
+                             rolenames.ROLE_PANEL, \
+                             rolenames.ROLE_OPTION_PANE, \
+                             rolenames.ROLE_DIALOG, \
+                             rolenames.ROLE_APPLICATION]
+                if self.isDesiredFocusedItem(event.source, rolesList):
+                    if event.source.parent.name.startswith(panelName):
+                        isPanel = True
+
+            if not isPanel:
+                rolesList = [rolenames.ROLE_PANEL, \
+                             rolenames.ROLE_OPTION_PANE, \
+                             rolenames.ROLE_DIALOG, \
+                             rolenames.ROLE_APPLICATION]
+                if self.isDesiredFocusedItem(event.source, rolesList):
+                    if event.source.name.startswith(panelName):
+                        isPanel = True
+
+        return isPanel
+
     # This method tries to detect and handle the following cases:
     # 0) Writer: find command.
     # 1) Writer: text paragraph.
@@ -1941,6 +1998,28 @@ class Script(default.Script):
         - event: the Event
         """
 
+        # Check to see if we are in the Presentation startup wizard. If so,
+        # then speak the object that currently has focus.
+        #
+        if event.type.startswith("object:state-changed:sensitive") and \
+           event.source.role == rolenames.ROLE_PANEL and \
+           event.source.state.count(atspi.Accessibility.STATE_SENSITIVE):
+            current = event.source.parent
+            while current.role != rolenames.ROLE_APPLICATION:
+                # Translators: this is the title of the window that
+                # you get when using StarOffice Presentation Wizard. The
+                # translated form has to match what
+                # StarOffice/OpenOffice is using.  We hate keying off
+                # stuff like this, but we're forced to do so in this
+                # case.
+                #
+                if current.role == rolenames.ROLE_DIALOG and \
+                   (current.name and current.name.startswith(_("Presentation Wizard"))):
+                    self.locusOfFocusChanged(event, None, 
+                                             orca_state.locusOfFocus)
+                    break
+                current = current.parent
+
         # If this is a state change "focused" event that we care about, and
         # we are in Writer, check to see if we are entering or leaving a table.
         #
@@ -2049,6 +2128,13 @@ class Script(default.Script):
             orca.setLocusOfFocus(event, event.source, False)
             return
 
+        # If we are in the sbase Table Wizard, try to reduce the numerous
+        # utterances of "Available fields panel". See bug #465087 for
+        # more details.
+        #
+        if self.__isAvailableFieldsPanel(event):
+            return
+
         # If we get "object:state-changed:focused" events for children of
         # a combo-box, just set the focus to the combo box. This is needed
         # to help reduce the verbosity of focusing on the Calc Name combo
