@@ -21,9 +21,9 @@
 fallback to local settings if the user settings doesn't exist (e.g., in the
 case of gdm) or doesn't have the specified attribute."""
 
-__id__        = "$Id: settings.py 2828 2007-09-13 19:26:33Z wwalker $"
-__version__   = "$Revision: 2828 $"
-__date__      = "$Date: 2007-09-13 15:26:33 -0400 (Thu, 13 Sep 2007) $"
+__id__        = "$Id: settings.py 2811 2007-09-10 22:40:26Z wwalker $"
+__version__   = "$Revision: 2811 $"
+__date__      = "$Date: 2007-09-10 18:40:26 -0400 (Mon, 10 Sep 2007) $"
 __copyright__ = "Copyright (c) 2005-2007 Sun Microsystems Inc."
 __license__   = "LGPL"
 
@@ -508,6 +508,15 @@ learnModeEnabled        = False
 #
 userPrefsDir = os.path.join(os.environ["HOME"], ".orca")
 
+# Assists with dealing with CORBA COMM_FAILURES.  A failure doesn't
+# always mean an object disappeared - there just might be a network
+# glitch.  So, on COMM_FAILURES, we might retry a few times before
+# giving up on an object.  This might need to be overridden by the
+# script.
+#
+commFailureWaitTime = 0.1
+commFailureAttemptLimit = 5
+
 # If non-zero, we use time.sleep() in various places to attempt to
 # free up the global interpreter lock.  Take a look at the following
 # URLs for more information:
