@@ -19,9 +19,9 @@
 
 """Speaks information about the current object of interest."""
 
-__id__        = "$Id: where_am_I.py 3025 2007-10-11 23:56:20Z joanied $"
-__version__   = "$Revision: 3025 $"
-__date__      = "$Date: 2007-10-11 19:56:20 -0400 (Thu, 11 Oct 2007) $"
+__id__        = "$Id: where_am_I.py 2955 2007-10-01 21:32:06Z joanied $"
+__version__   = "$Revision: 2955 $"
+__date__      = "$Date: 2007-10-01 17:32:06 -0400 (Mon, 01 Oct 2007) $"
 __copyright__ = "Copyright (c) 2005-2007 Sun Microsystems Inc."
 __license__   = "LGPL"
 
@@ -47,6 +47,7 @@ class WhereAmI:
         self._script = script
         self._debugLevel = debug.LEVEL_FINEST
         self._statusBar = None
+        self._defaultButton = None
         self._lastAttributeString = ""
 
     def whereAmI(self, obj, doubleClick, orcaKey):
@@ -214,6 +215,7 @@ class WhereAmI:
             # ONLY TRANSLATE THE PART AFTER THE PIPE CHARACTER |
             #
             text = Q_("radiobutton|not selected")
+
         utterances.append(text)
 
         text = self._getPositionInGroup(obj)
@@ -1128,7 +1130,7 @@ class WhereAmI:
                         if prevObj.text.getNSelections() > 0:
                             [newTextContents, start, end] = \
                                          self._getTextSelection(prevObj)
-                            textContents = newTextContents + " " + textContents
+                            textContents = newTextContents + textContents
                             current = prevObj
                             morePossibleSelections = True
                         else:
@@ -1150,7 +1152,7 @@ class WhereAmI:
                         if nextObj.text.getNSelections() > 0:
                             [newTextContents, start, end] = \
                                          self._getTextSelection(nextObj)
-                            textContents += " " + newTextContents
+                            textContents += newTextContents
                             current = nextObj
                             morePossibleSelections = True
                         else:
@@ -1412,7 +1414,9 @@ class WhereAmI:
                     self._speakStatusBar()
             window = list[1] or list[0]
             if window:
-                self._speakDefaultButton(window)
+                self._defaultButton = None
+                self._getDefaultButton(window)
+                self._speakDefaultButton()
         else:
             if list[0]:
                 text = self._getObjLabelAndName(list[0])
@@ -1500,8 +1504,10 @@ class WhereAmI:
         Arguments:
         - obj: the dialog box for which the default button should be obtained
         """
+        
+        if self._defaultButton:
+            return
 
-        defaultButton = None
         for i in range(0, obj.childCount):
             child = obj.child(i)
             # debug.println(self._debugLevel,
@@ -1509,25 +1515,18 @@ class WhereAmI:
             #               (child.role, self._getObjLabelAndName(child)))
             if child.role == rolenames.ROLE_PUSH_BUTTON \
                 and child.state.count(atspi.Accessibility.STATE_IS_DEFAULT):
-                defaultButton = child
-            else:
-                defaultButton = self._getDefaultButton(child)
+                self._defaultButton = child
+                return
 
-            if defaultButton:
-                break
+            if child.childCount > 0:
+                self._getDefaultButton(child)
 
-        return defaultButton
-
-    def _speakDefaultButton(self, obj):
+    def _speakDefaultButton(self):
         """Speaks the default button in a dialog.
-
-        Arguments:
-        - obj: the dialog box for which the default button should be obtained
         """
 
-        defaultButton = self._getDefaultButton(obj)
-        if not defaultButton \
-           or not defaultButton.state.count(\
+        if not self._defaultButton \
+           or not self._defaultButton.state.count(\
                                       atspi.Accessibility.STATE_SENSITIVE):
             return
 
@@ -1538,7 +1537,7 @@ class WhereAmI:
         # dialog box.
         #
         text = _("Default button is %s") % \
-               self._getObjName(defaultButton)
+               self._getObjName(self._defaultButton)
         utterances.append(text)
 
         debug.println(self._debugLevel, "default button utterances=%s" % \
